@@ -1,13 +1,15 @@
 ;;; no-littering.el --- Help keeping ~/.config/emacs clean  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2025 Jonas Bernoulli
+;; Copyright (C) 2016-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.no-littering@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 1.8.0
-;; Package-Requires: ((emacs "26.1") (compat "30.1"))
+;; Package-Version: 1.8.3
+;; Package-Requires: (
+;;     (emacs  "26.1")
+;;     (compat "30.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -132,7 +134,10 @@ This variable has to be set before `no-littering' is loaded.")
     (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq erc-dcc-get-default-directory    (var "erc/dcc/"))
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
-    (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
+    (setq erc-startup-file-list            (list (etc "erc/startup.el")
+                                                 (etc "erc/startup")
+                                                 ".ercrc.el"
+                                                 ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
     ;; This controls where `eshell-history-file-name' is places.
     ;; Other files belong in "etc/" so theme their variables directly.
@@ -198,6 +203,7 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'newsticker  `(make-directory ,(var "newsticker/") t))
     (eval-after-load 'org         `(make-directory ,(var "org/") t))
     (eval-after-load 'shadowfile  `(make-directory ,(var "shadow/") t))
+    (eval-after-load 'treesit     `(push ,(var "treesit/") treesit-extra-load-path))
 
 ;;; Third-party packages
 
@@ -207,6 +213,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq anaconda-mode-installation-directory (var "anaconda-mode/"))
     (setq annotate-file                    (var "annotations.el"))
     (setq async-byte-compile-log-file      (var "async-bytecomp.log"))
+    (setq autocrypt-save-file              (var "autocrypt-data.eld"))
     (setq auto-package-update-last-update-day-path (var "auto-package-update-last-update-day"))
     (setq bbdb-file                        (var "bbdb/bbdb.el"))
     (setq bbdb-vcard-directory             (var "bbdb/vcard/"))
@@ -265,6 +272,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq gnus-notes-file                  (var "gnus-notes/articles.el"))
     (setq gnus-notes-top-dir               (var "gnus-notes/"))
     (setq gptel-crowdsourced-prompts-file  (var "gptel-crowdsourced-prompts.csv"))
+    (setq gptel-gh-token-file              (var "gptel/gh-token"))
+    (setq gptel-gh-github-token-file       (var "gptel/gh-github-token"))
     (setq grammalecte-settings-file        (etc "grammalecte-settings.el"))
     (setq hackernews-visited-links-file    (var "hackernews/visited-links.el"))
     (setq harpoon-cache-file               (var "harpoon/"))
@@ -479,5 +488,6 @@ you must turn of these features completely."
 (provide 'no-littering)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; no-littering.el ends here
